import request from '@/utils/request'

// 查询企业信息管理财务数据列表
export function listInfo(query) {
  return request({
    url: '/buyer/companydata/list',
    method: 'get',
    params: query
  })
}

// 查询该年度是否已有数据
export function checkYearExist(query) {
  return request({
    url: '/buyer/companydata/check',
    method: 'get',
    params: query
  })
}

// 查询会员企业信息详细
export function getInfo(id) {
  return request({
    url: '/buyer/companydata/' + id,
    method: 'get'
  })
}

// 新增企业信息管理财务数据
export function addInfo(data) {
  return request({
    url: '/buyer/companydata',
    method: 'post',
    data: data
  })
}

// 修改会员企业信息
export function updateInfo(data) {
  return request({
    url: '/buyer/companydata',
    method: 'put',
    data: data
  })
}

// 删除会员企业信息
export function delInfo(id) {
  return request({
    url: '/buyer/companydata/' + id,
    method: 'delete'
  })
}

// 查询会员企业信息详细
export function getCompanyInfo(id) {
  return request({
    url: '/buyer/company/' + id,
    method: 'get'
  })
}

// 修改会员企业信息
export function updateCompanyInfo(data) {
  return request({
    url: '/buyer/company',
    method: 'put',
    data
  })
}

// 新增会员企业信息
export function addCompanyInfo(data) {
  return request({
    url: '/buyer/company',
    method: 'post',
    data: data
  })
}
